@@ -35,6 +35,9 @@
 #include <ctime>
 #include <iostream>
 #include <iterator>
+#if defined(_MSC_VER)
+#include <io.h>
+#endif
 
 #include <boost/foreach.hpp>
 #include <boost/regex.hpp>
@@ -140,7 +143,7 @@ dump_data (ImageInput *input, const print_info_options &opt)
 
     } else {
         std::vector<float> buf(spec.image_pixels() * spec.nchannels);
-        if (! input->read_image (TypeDesc::UNKNOWN /*native*/, &buf[0])) {
+        if (! input->read_image (TypeDesc::FLOAT, &buf[0])) {
             printf ("    dump data: could not read image\n");
             return;
         }
@@ -261,10 +264,11 @@ print_stats (Oiiotool &ot,
         ot.error ("stats", input.geterror());
         return;
     }
-    
     PixelStats stats;
     if (! computePixelStats (stats, input)) {
-        ot.error ("stats", "unable to compute");
+        std::string err = input.geterror();
+        ot.error ("stats", Strutil::format ("unable to compute: %s",
+                                            err.empty() ? "unspecified error" : err.c_str()));
         return;
     }
     
